==> huaweicloudsdkvpc-3.1.94-py2.py3-none-any.whl: huaweicloudsdkvpc/v3/model/remove_security_groups_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class RemoveSecurityGroupsRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'port': 'RemoveSecurityGroupOption'
    }

    attribute_map = {
        'port': 'port'
    }

    def __init__(self, port=None):
        """RemoveSecurityGroupsRequestBody

        The model defined in huaweicloud sdk

        :param port: 
        :type port: :class:`huaweicloudsdkvpc.v3.RemoveSecurityGroupOption`
        """
        
        

        self._port = None
        self.discriminator = None

        self.port = port

    @property
    def port(self):
        """Gets the port of this RemoveSecurityGroupsRequestBody.

        :return: The port of this RemoveSecurityGroupsRequestBody.
        :rtype: :class:`huaweicloudsdkvpc.v3.RemoveSecurityGroupOption`
        """
        return self._port

    @port.setter
    def port(self, port):
        """Sets the port of this RemoveSecurityGroupsRequestBody.

        :param port: The port of this RemoveSecurityGroupsRequestBody.
        :type port: :class:`huaweicloudsdkvpc.v3.RemoveSecurityGroupOption`
        """
        self._port = port

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RemoveSecurityGroupsRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkvpc-3.1.150-py2.py3-none-any.whl: huaweicloudsdkvpc/v3/model/remove_security_groups_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class RemoveSecurityGroupsRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'port': 'RemoveSecurityGroupOption'
    }

    attribute_map = {
        'port': 'port'
    }

    def __init__(self, port=None):
        r"""RemoveSecurityGroupsRequestBody

        The model defined in huaweicloud sdk

        :param port: 
        :type port: :class:`huaweicloudsdkvpc.v3.RemoveSecurityGroupOption`
        """
        
        

        self._port = None
        self.discriminator = None

        self.port = port

    @property
    def port(self):
        r"""Gets the port of this RemoveSecurityGroupsRequestBody.

        :return: The port of this RemoveSecurityGroupsRequestBody.
        :rtype: :class:`huaweicloudsdkvpc.v3.RemoveSecurityGroupOption`
        """
        return self._port

    @port.setter
    def port(self, port):
        r"""Sets the port of this RemoveSecurityGroupsRequestBody.

        :param port: The port of this RemoveSecurityGroupsRequestBody.
        :type port: :class:`huaweicloudsdkvpc.v3.RemoveSecurityGroupOption`
        """
        self._port = port

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RemoveSecurityGroupsRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
